# DJANGO CLI

## Description

This is a small project created with the initial purpose of facilitating, through a single command, the creation of views, templates, models, serializers and basic endpoints for the django web framework together with the django rest framework.
You can see in :
  
[Django-Cli](https://github.com/wdavid73/django-cli)
  
[Django-Cli in PyPi](https://pypi.org/project/django-cli-g73/#description)

## Requirements

1. python 3.7+

## Usage

before using any command in the package first go to your django project folder and start your virtual environment before user the command `pip install django-cli-g73`

## Install Manually

git clone <https://github.com/wdavid73/django-cli>

enter to the folder django-cli
  
run the command : `python setup.py`

## Commands local

1. python cli/main.py make-view
2. python cli/main.py make-template
3. python cli/main.py make-model
4. python cli/main.py make-serializer
5. python cli/main.py make-endpoint

## Commands

1. django-cli make-view
2. django-cli make-template
3. django-cli make-model
4. django-cli make-serializer
5. django-cli make-endpoint
